@@ -153,13 +153,15 @@ API Reference
 # stdlib
 import inspect
 import warnings
-from typing import Any, Callable, Dict, List, Optional, Tuple
+from typing import Any, Callable, Dict, List, MutableMapping, Optional, Tuple
 
 # 3rd party
+import dict2css
 import sphinx.environment
 from docutils import nodes
 from docutils.parsers.rst import directives
 from docutils.statemachine import ViewList
+from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.words import word_join
 from sphinx.application import Sphinx
@@ -180,9 +182,13 @@ __all__ = [
 		"github_installation",
 		"installation_node_purger",
 		"extensions_node_purger",
+		"copy_asset_files",
 		"setup",
 		]
 
+installation_node_purger = Purger("all_installation_node_nodes")
+extensions_node_purger = Purger("all_extensions_node_nodes")
+
 
 class Sources(List[Tuple[str, str, Callable, Callable, Optional[Dict[str, Callable]]]]):
 	"""
@@ -526,8 +532,67 @@ class ExtensionsDirective(SphinxDirective):
 		return [targetnode, extensions_node]
 
 
-installation_node_purger = Purger("all_installation_node_nodes")
-extensions_node_purger = Purger("all_extensions_node_nodes")
+def copy_asset_files(app: Sphinx, exception: Exception = None):
+	"""
+	Copy additional stylesheets into the HTML build directory.
+
+	:param app: The Sphinx application.
+	:param exception: Any exception which occurred and caused Sphinx to abort.
+
+	.. versionadded:: 1.2.0
+	"""
+
+	if exception:  # pragma: no cover
+		return
+
+	style: MutableMapping[str, dict2css.Style] = {
+			'div[id*="installation"] .sphinx-tabs-tab': {"color": "#2980b9"},
+			"button.sphinx-tabs-tab,div.sphinx-tabs-panel": {"outline": (None, dict2css.IMPORTANT)},
+			}
+
+	static_dir = PathPlus(app.outdir) / "_static"
+	static_dir.maybe_make(parents=True)
+	(static_dir / "sphinx_toolbox_installation.css").write_clean(dict2css.dumps(style, minify=True))
+	(static_dir / "sphinx_toolbox_installation.js").write_lines([
+			"// Based on https://github.com/executablebooks/sphinx-tabs/blob/master/sphinx_tabs/static/tabs.js",
+			"// Copyright (c) 2017 djungelorm",
+			"// MIT Licensed",
+			'',
+			"function deselectTabset(target) {",
+			"  const parent = target.parentNode;",
+			"  const grandparent = parent.parentNode;",
+			'',
+			'  if (parent.parentNode.parentNode.getAttribute("id").startsWith("installation")) {',
+			'',
+			"    // Hide all tabs in current tablist, but not nested",
+			"    Array.from(parent.children).forEach(t => {",
+			'      if (t.getAttribute("name") !== target.getAttribute("name")) {',
+			'        t.setAttribute("aria-selected", "false");',
+			"      }",
+			"    });",
+			'',
+			"    // Hide all associated panels",
+			"    Array.from(grandparent.children).slice(1).forEach(p => {  // Skip tablist",
+			'      if (p.getAttribute("name") !== target.getAttribute("name")) {',
+			'        p.setAttribute("hidden", "false")',
+			"      }",
+			"    });",
+			"  }",
+			'',
+			"  else {",
+			"    // Hide all tabs in current tablist, but not nested",
+			"    Array.from(parent.children).forEach(t => {",
+			'      t.setAttribute("aria-selected", "false");',
+			"    });",
+			'',
+			"    // Hide all associated panels",
+			"    Array.from(grandparent.children).slice(1).forEach(p => {  // Skip tablist",
+			'      p.setAttribute("hidden", "true")',
+			"    });",
+			"  }",
+			'',
+			'}',
+			])
 
 
 def setup(app: Sphinx) -> SphinxExtMetadata:
@@ -557,6 +622,11 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.add_directive("extensions", ExtensionsDirective)
 	app.connect("env-purge-doc", extensions_node_purger.purge_nodes)
 
+	# Little CSS tweaks
+	app.add_css_file("sphinx_toolbox_installation.css")
+	app.add_js_file("sphinx_toolbox_installation.js")
+	app.connect("build-finished", copy_asset_files)
+
 	return {
 			"version": __version__,
 			"parallel_read_safe": True,
