@@ -10,7 +10,7 @@ Functions for testing Sphinx extensions.
 .. seealso:: Sphinx's own ``testing`` library: https://github.com/sphinx-doc/sphinx/tree/3.x/sphinx/testing
 """
 #
-#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
+#  Copyright © 2020-2021 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -60,17 +60,22 @@ Functions for testing Sphinx extensions.
 
 # stdlib
 import copy
+import tempfile
+from types import SimpleNamespace
 from typing import Any, Callable, Dict, List, NamedTuple, Optional, Set, Tuple, Type, Union
 
 # 3rd party
+import pytest  # nodep
 import sphinx.application
 from bs4 import BeautifulSoup  # type: ignore
 from docutils import nodes
 from docutils.parsers.rst import Directive, roles
 from docutils.transforms import Transform
 from domdf_python_tools.doctools import prettify_docstrings
+from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
-from domdf_python_tools.testing import check_file_regression
+from domdf_python_tools.testing import check_file_output, check_file_regression
+from domdf_python_tools.typing import PathLike
 from pygments.lexer import Lexer  # type: ignore  # nodep
 from pytest_regressions.file_regression import FileRegressionFixture  # nodep
 from sphinx.builders import Builder
@@ -98,6 +103,9 @@ __all__ = [
 		"remove_html_footer",
 		"check_html_regression",
 		"remove_html_link_tags",
+		"check_asset_copy",
+		"HTMLRegressionFixture",
+		"html_regression",
 		]
 
 
@@ -532,21 +540,21 @@ class RunSetupOutput(NamedTuple):
 	:class:`~typing.NamedTuple` representing the output from :func:`~sphinx_toolbox.testing.run_setup`.
 	"""
 
-	setup_ret: Union[Dict[str, Any], "SphinxExtMetadata"]  #: The output from the ``setup()`` function.
+	setup_ret: Union[None, Dict[str, Any], "SphinxExtMetadata"]  #: The output from the ``setup()`` function.
 	directives: Dict[str, Callable]  #: Mapping of directive names to directive functions.
 	roles: Dict[str, Callable]  #: Mapping of role names to role functions.
 	additional_nodes: Set[Type[Any]]  #: Set of custom docutils nodes registered in ``setup()``.
 	app: Sphinx  #: Instance of :class:`sphinx-toolbox.testing.Sphinx`.
 
 
-_sphinx_dict_setup = Callable[[sphinx.application.Sphinx], Dict[str, Any]]
-_sphinx_metadata_setup = Callable[[sphinx.application.Sphinx], "SphinxExtMetadata"]
-_fake_dict_setup = Callable[[Sphinx], Dict[str, Any]]
-_fake_metadata_setup = Callable[[Sphinx], "SphinxExtMetadata"]
+_sphinx_dict_setup = Callable[[sphinx.application.Sphinx], Optional[Dict[str, Any]]]
+_sphinx_metadata_setup = Callable[[sphinx.application.Sphinx], Optional["SphinxExtMetadata"]]
+_fake_dict_setup = Callable[[Sphinx], Optional[Dict[str, Any]]]
+_fake_metadata_setup = Callable[[Sphinx], Optional["SphinxExtMetadata"]]
 _setup_func_type = Union[_sphinx_dict_setup, _sphinx_metadata_setup, _fake_dict_setup, _fake_metadata_setup]
 
 
-def run_setup(setup_func: _setup_func_type, ) -> RunSetupOutput:  # , buildername: str = "html"
+def run_setup(setup_func: _setup_func_type) -> RunSetupOutput:  # , buildername: str = "html"
 	"""
 	Function for running an extension's ``setup()`` function for testing.
 
@@ -627,6 +635,8 @@ def check_html_regression(page: BeautifulSoup, file_regression: FileRegressionFi
 			check_html_regression(page, file_regression)
 	"""  # noqa D400
 
+	__tracebackhide__ = True
+
 	page = remove_html_footer(page)
 	page = remove_html_link_tags(page)
 
@@ -639,3 +649,91 @@ def check_html_regression(page: BeautifulSoup, file_regression: FileRegressionFi
 			file_regression,
 			extension=".html",
 			)
+
+
+class HTMLRegressionFixture(FileRegressionFixture):
+	"""
+	Subclass of :class:`pytest_regressions.file_regression.FileRegressionFixture`
+	for checking HTML files.
+
+	.. versionadded:: 2.0.0
+	"""  # noqa: D400
+
+	def check(self, page: BeautifulSoup, **kwargs):  # type: ignore
+		r"""
+		Check an HTML page generated by Sphinx for regressions,
+		using `pytest-regressions <https://pypi.org/project/pytest-regressions/>`_
+
+		:param page: The page to test.
+		:param \*\*kwargs: Additional keyword arguments passed to
+			:meth:`pytest_regressions.file_regression.FileRegressionFixture.check`.
+
+		**Example usage**
+
+		.. code-block:: python
+
+			@pytest.mark.parametrize("page", ["index.html"], indirect=True)
+			def test_page(page: BeautifulSoup, html_regression: HTMLRegressionFixture):
+				html_regression.check(page, file_regression)
+		"""  # noqa D400
+
+		__tracebackhide__ = True
+
+		page = remove_html_footer(page)
+		page = remove_html_link_tags(page)
+
+		for div in page.select("script"):
+			if "_static/language_data.js" in str(div):
+				div.extract()
+
+		kwargs.pop("encoding", None)
+		kwargs.pop("extension", None)
+
+		super().check(
+				str(StringList(page.prettify())),
+				encoding="UTF-8",
+				extension=".html",
+				)
+
+
+@pytest.fixture()
+def html_regression(datadir, original_datadir, request) -> HTMLRegressionFixture:
+	"""
+	Returns a :class:`~.HTMLRegressionFixture` scoped to the test function.
+
+	.. versionadded:: 2.0.0
+	"""
+
+	return HTMLRegressionFixture(datadir, original_datadir, request)
+
+
+def check_asset_copy(
+		func: Callable[[sphinx.application.Sphinx, Exception], Any],
+		*asset_files: PathLike,
+		file_regression: FileRegressionFixture,
+		):
+	r"""
+	Helper to test functions which respond to Sphinx ``build-finished`` events and copy asset files.
+
+	.. versionadded:: 2.0.0
+
+	:param func: The function to test.
+	:param \*asset_files: The paths of asset files copied by the function, relative to the Sphinx output directory.
+	:param file_regression:
+	"""
+
+	__tracebackhide__ = True
+
+	with tempfile.TemporaryDirectory() as tmpdir:
+		tmp_pathplus = PathPlus(tmpdir)
+
+		fake_app = SimpleNamespace()
+		fake_app.builder = SimpleNamespace()
+		fake_app.outdir = fake_app.builder.outdir = tmp_pathplus
+
+		func(fake_app, None)  # type: ignore
+
+		for filename in asset_files:
+			filename = tmp_pathplus / filename
+
+			check_file_output(filename, file_regression, extension=f"_{filename.stem}{filename.suffix}")
